#
# Ubuntu PractiTest Community results processor
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""SSO authentication."""

import json
import requests
import logging
import os
from werkzeug.exceptions import Unauthorized

logger = logging.getLogger(__name__)

# Use staging if we running devel.
SSO_BASE_URL = 'https://login.ubuntu.com/api/v2'
if os.environ.get('DEPLOY_STAGE', 'production') == 'devel':
    # Use the following for SSO staging:
    SSO_BASE_URL = 'https://login.staging.ubuntu.com/api/v2'


JSON_HEADERS = {
    'Content-Type': 'application/json',
    'Accept': 'application/json',
}


def validate_request(response):
    """Validate an sso request.

    :param request: flask request object.

    :raises: exception if not valid.

    """
    try:
        data = dict(
            http_url=response.url,
            http_method=response.method,
            authorization=response.headers['Authorization'])
    except KeyError:
        logger.error(
            'Auth Failed: No authorization details found in header'
        )
        raise Unauthorized('No authorization details found.')

    validate_response = requests.post(
        SSO_BASE_URL + '/requests/validate', json.dumps(data),
        headers=JSON_HEADERS)
    if not validate_response.ok:
        logger.error('Validation failed against login server.')
        raise Unauthorized('Validation failed against login server.')
    return validate_response.json()
