#
# Ubuntu PractiTest Community results processor
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
from flask import render_template

from ubuntu_pt_community.pages import reports


logger = logging.getLogger(__name__)


class PageDefinition:

    def __init__(self, name, route_name, route_func):
        """Encapsulate the report view details."""
        self.name = name
        self.route_name = route_name
        self.route_func = route_func

    @property
    def route_function_name(self):
        """Return the name of the route function for use_url."""
        return self.route_func.__name__


# Keep a list of report pages so we don't have to duplicate things when listing
# them and adding routes.
Report_Pages = [
    PageDefinition(
        'All Results',
        '/reports/all_results',
        reports.view_all_results
    ),

    PageDefinition(
        'Latest Uploads',
        '/reports/latest',
        reports.view_latest_uploads
    ),
]


def define_routes(webapp):
    """Setup all routes for available reports (incl. list of reports."""
    webapp.add_url_rule('/reports', view_func=view_reports)

    for page in Report_Pages:
        webapp.add_url_rule(page.route_name, view_func=page.route_func)


def view_reports():
    """Render a simple list of links to available reports."""
    return render_template('results/index.html', reports=Report_Pages)
